==> numpy-sugar-1.0.16.tar.gz: numpy-sugar-1.0.16/setup.py <==
import os
import sys
from os.path import join

from setuptools import find_packages, setup

try:
    import pypandoc
    long_description = pypandoc.convert_file('README.md', 'rst')
except (OSError, IOError, ImportError):
    long_description = open('README.md').read()


def get_capi_lib():
    from build_capi import CApiLib
    from ncephes import get_include

    sources = [join('numpy_sugar', 'special', 'special.c')]
    hdrs = [join('numpy_sugar', 'special', 'special.h')]
    incls = [join('numpy_sugar', 'include'), get_include()]

    return CApiLib(
        name='numpy_sugar.lib.numpy_sugar',
        sources=sources,
        include_dirs=incls,
        depends=hdrs)


def setup_package():
    src_path = os.path.dirname(os.path.abspath(sys.argv[0]))
    old_path = os.getcwd()
    os.chdir(src_path)
    sys.path.insert(0, src_path)

    needs_pytest = {'pytest', 'test', 'ptr'}.intersection(sys.argv)
    pytest_runner = ['pytest-runner'] if needs_pytest else []

    setup_requires = [
        'build-capi',
        'ncephes',
        'cffi',
    ] + pytest_runner
    install_requires = ['ncephes', 'scipy', 'numpy', 'cffi']
    tests_require = ['pytest>=3']

    recommended = {"numba": ["numba>=0.28"]}

    metadata = dict(
        name='numpy-sugar',
        version='1.0.16',
        maintainer="Danilo Horta",
        maintainer_email="horta@ebi.ac.uk",
        license="MIT",
        description="Missing NumPy functionalities.",
        long_description=long_description,
        url='http://github.com/glimix/numpy-sugar',
        packages=find_packages(),
        zip_safe=False,
        cffi_modules=['special_build.py:special'],
        install_requires=install_requires,
        tests_require=tests_require,
        setup_requires=setup_requires,
        extras_require=recommended,
        include_package_data=True,
        capi_libs=[get_capi_lib],
        classifiers=[
            "Development Status :: 5 - Production/Stable",
            "Intended Audience :: Developers",
            "License :: OSI Approved :: MIT License",
            "Programming Language :: Python :: 2.7",
            "Programming Language :: Python :: 3.5",
            "Operating System :: OS Independent",
        ],
        package_data={'': [join('numpy_sugar', 'lib', '*.*')]})

    try:
        setup(**metadata)
    finally:
        del sys.path[0]
        os.chdir(old_path)


if __name__ == '__main__':
    setup_package()

==> numpy-sugar-1.0.17.tar.gz: numpy-sugar-1.0.17/setup.py <==
import os
import sys
from os.path import join

from setuptools import find_packages, setup

try:
    import pypandoc
    long_description = pypandoc.convert_file('README.md', 'rst')
except (OSError, IOError, ImportError):
    long_description = open('README.md').read()


def get_capi_lib():
    from build_capi import CApiLib
    from ncephes import get_include

    sources = [join('numpy_sugar', 'special', 'special.c')]
    hdrs = [join('numpy_sugar', 'special', 'special.h')]
    incls = [join('numpy_sugar', 'include'), get_include()]

    return CApiLib(
        name='numpy_sugar.lib.numpy_sugar',
        sources=sources,
        include_dirs=incls,
        depends=hdrs)


def setup_package():
    src_path = os.path.dirname(os.path.abspath(sys.argv[0]))
    old_path = os.getcwd()
    os.chdir(src_path)
    sys.path.insert(0, src_path)

    needs_pytest = {'pytest', 'test', 'ptr'}.intersection(sys.argv)
    pytest_runner = ['pytest-runner'] if needs_pytest else []

    setup_requires = [
        'build-capi',
        'ncephes',
    ] + pytest_runner
    install_requires = ['ncephes', 'scipy', 'numpy']
    tests_require = ['pytest>=3']

    recommended = {"numba": ["numba>=0.28"]}

    if '_cffi_backend' in sys.builtin_module_names:
        import _cffi_backend
        requires_cffi = ["cffi==" + _cffi_backend.__version__]
    else:
        requires_cffi = ["cffi>=1.1.0"]

    setup_requires += requires_cffi
    install_requires += requires_cffi

    metadata = dict(
        name='numpy-sugar',
        version='1.0.17',
        maintainer="Danilo Horta",
        maintainer_email="horta@ebi.ac.uk",
        license="MIT",
        description="Missing NumPy functionalities.",
        long_description=long_description,
        url='http://github.com/glimix/numpy-sugar',
        packages=find_packages(),
        zip_safe=False,
        cffi_modules=['special_build.py:special'],
        install_requires=install_requires,
        tests_require=tests_require,
        setup_requires=setup_requires,
        extras_require=recommended,
        include_package_data=True,
        capi_libs=[get_capi_lib],
        classifiers=[
            "Development Status :: 5 - Production/Stable",
            "Intended Audience :: Developers",
            "License :: OSI Approved :: MIT License",
            "Programming Language :: Python :: 2.7",
            "Programming Language :: Python :: 3.5",
            "Operating System :: OS Independent",
        ],
        package_data={'': [join('numpy_sugar', 'lib', '*.*')]})

    try:
        setup(**metadata)
    finally:
        del sys.path[0]
        os.chdir(old_path)


if __name__ == '__main__':
    setup_package()
